# Contributors

## Main code development
- Uwe Hernandez Acosta (HZDR/CASUS) <u.hernandez@hzdr.de>
- Sachin Krishnan Thekke Veettil (HZDR/CASUS) <s.thekke-veettil@hzdr.de>
- Damar Wicaksono (HZDR/CASUS) <d.wicaksono@hzdr.de>


## Mathematical foundation
- Michael Hecht(HZDR/CASUS) <m.hecht@hzdr.de>

## Former Members and Contributions
- Jannik Michelfeit
- Nico Hoffman (HZDR)
- Steve Schmerler (HZDR)
- Vidya Chandrashekar (TU Dresden)

## Acknowledgement
- Klaus Steiniger (HZDR)
- Patrick Stiller (HZDR)
- Matthias Werner (HZDR)
- Krzysztof Gonciarz (MPI-CBG,CSBD)
- Attila Cangi (HZDR/CASUS)
- Michael Bussmann (HZDR/CASUS)
